@@ -7,10 +7,8 @@ from oslo_log import log as logging
 import debugpy
 from oslo_config import cfg
 
-def init():
+def init(CONF=cfg.CONF):
     """원격 디버거 초기화"""
-    CONF = cfg.CONF
-
     if 'remote_debug' not in CONF:
         return
 
